OpenDebates for Discord
=======================

|image0|

|image1| |image2|

-----------------------------------------------

What is OpenDebates for Discord?
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

It is a bot for discord, that allows users to participate in debates that are ranked by ELO ratings.

.. |image0| image:: https://i.imgur.com/SxX5wQF.png
   :width: 100px
   :target: https://opendebates.rtfd.io
.. |image1| image:: https://travis-ci.com/OpenDebates/OpenDebates.svg?branch=master
   :target: https://travis-ci.com/OpenDebates/OpenDebates
.. |image2| image:: https://readthedocs.org/projects/opendebates/badge/?version=latest
   :target: https://opendebates.readthedocs.io/en/latest/?badge=latest
